function nu = tsnu(T)

% NU = TSNU(T)
%
% Returns the "backward-graininess" of timescale T as a timescale object NU. By convention,
% the size of NU will be the size of T, with NU(1) = 0.
%

% Ian Gravagne, 12/29/03 Baylor University

if(~isa(T,'timescale'))
    error('Backward graininess function TSNU requries a timescale object for input.');
end

t = T(:);
s = size(T);

if(isempty(t) | isempty(s))
    nu = T;
    return;
end

D = isdiscrete(T);
d = D(:);

for(i = [1:size(s,2)-1])
    if(s(1,i) < length(d))
        d(s(1,i)+1) = 1;
    end
end

grain = [0,-diff(t)].*d;

nu = timescale(grain,size(T));
